@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2016 - 2019
+;;;; Copyright (C) 2016 - 2023
 ;;;; Free Software Foundation, Inc.
 
 ;;;; This file is part of GNU Guile-CV.
@@ -37,11 +37,12 @@
   #:use-module (cv support)
   #:use-module (cv idata)
   #:use-module (cv impex)
-  #:use-module (cv imgproc)
-  #:use-module (cv adds)
-  #:use-module (cv features)
-  #:use-module (cv segmentation)
   #:use-module (cv utils)
+  #:use-module (cv segmentation)
+  #:use-module (cv features)
+  #:use-module (cv process)
+  #:use-module (cv transform)
+  #:use-module (cv particles)
 
   #:duplicates (merge-generics
 		replace
