@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2016 - 2017
+;;;; Copyright (C) 2016 - 2018
 ;;;; Free Software Foundation, Inc.
 
 ;;;; This file is part of GNU Guile-CV.
@@ -340,6 +340,12 @@
 (define %axa'xa
   `(2 3 1 (,#f32(123.0 156.0 281.0 356.0 439.0 556.0))))
 
+(define %a*a
+  `(2 3 1 (,#f32(1.0 4.0 9.0 16.0 25.0 36.0))))
+
+(define %a/a
+  `(2 3 1 (,#f32(1.0 1.0 1.0 1.0 1.0 1.0))))
+
 (define-method (test-im-add (self <guile-cv-tests-cv>))
   (assert-true (im-=? (im-add %a 1.0) %b))
   (assert-true (im-=? (im-add %a %b) %a+b))
@@ -350,10 +356,13 @@
   (assert-true (im-=? (im-subtract %a %b) %a-b))
   (assert-true (im-=? (im-subtract %a %b %c) %a-b-c)))
 
-(define-method (test-im-multiply (self <guile-cv-tests-cv>))
-  (assert-true (im-=? (im-multiply %a 2.0) %c))
-  (assert-true (im-=? (im-multiply %a %a') %axa'))
-  (assert-true (im-=? (im-multiply %a %a' %a) %axa'xa)))
+(define-method (test-im-times (self <guile-cv-tests-cv>))
+  (assert-true (im-=? (im-times %a 2.0) %c))
+  (assert-true (im-=? (im-times %a %a) %a*a)))
+
+(define-method (test-im-mtimes (self <guile-cv-tests-cv>))
+  (assert-true (im-=? (im-mtimes %a %a') %axa'))
+  (assert-true (im-=? (im-mtimes %a %a' %a) %axa'xa)))
 
 (define %d1
   `(2 3 1 (,#f32(2.0 4.0 8.0 16.0 32.0 64.0))))
@@ -376,8 +385,11 @@
 
 (define-method (test-im-divide (self <guile-cv-tests-cv>))
   (assert-true (im-=? 0.0 (im-divide %d1 2.0) %d2))
-  (assert-true (im-=? (im-divide %d1 %d4) %d5))
-  (assert-true (im-=? (im-divide %d1 %d4 %d6) %d7)))
+  (assert-true (im-=? 0.0 (im-divide %a %a) %a/a)))
+
+(define-method (test-im-mdivide (self <guile-cv-tests-cv>))
+  (assert-true (im-=? (im-mdivide %d1 %d4) %d5))
+  (assert-true (im-=? (im-mdivide %d1 %d4 %d6) %d7)))
 
 (define (make-scrap-test-image)
   (let ((img (im-make 12 12 1)))
@@ -480,7 +492,10 @@
 
 (define %texture-test-image
   (list 4 4 1
-        (list #f32(0 0 1 1 0 0 1 1 0 2 2 2 2 2 3 3))))
+        (list #f32(0 0 1 1
+                   0 0 1 1
+                   0 2 2 2
+                   2 2 3 3))))
 
 (define  %texture-test-image-2
   (list 4 4 1
